summaryrefslogtreecommitdiffstats
path: root/smb4k/listview/smb4kshareslistviewitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/listview/smb4kshareslistviewitem.h')
-rw-r--r--smb4k/listview/smb4kshareslistviewitem.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/smb4k/listview/smb4kshareslistviewitem.h b/smb4k/listview/smb4kshareslistviewitem.h
index b47f888..a944def 100644
--- a/smb4k/listview/smb4kshareslistviewitem.h
+++ b/smb4k/listview/smb4kshareslistviewitem.h
@@ -144,13 +144,13 @@ class Smb4KSharesListViewItem : public KListViewItem
*
* @param width The width of the area that will be painted.
*
* @param tqalignment The tqalignment of the column that will be used.
*/
void paintCell( TQPainter *p,
const TQColorGroup &cg,
int column,
int width,
- int tqalignment );
+ int alignment );
/**
* Reimplemented from KListViewItem.
@@ -144,13 +144,13 @@ class Smb4KSharesListViewItem : public KListViewItem
* @param width The width of the area that will be painted.
*
- * @param tqalignment The tqalignment of the column that will be used.
+ * @param alignment The alignment of the column that will be used.
*/
void paintCell( TQPainter *p,